# ifndef yyAdaptAnalysis
# define yyAdaptAnalysis

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)	parameters
# else
# define ARGS(parameters)	()
# endif

# ifndef rbool
# define rbool char
# endif

# include "Tree.h"
# include "Definitions.h"


extern void (* AdaptAnalysis_Exit) ARGS ((void));

extern void AdaptAnalysis ARGS ((tTree t));

extern void BeginAdaptAnalysis ARGS ((void));
extern void CloseAdaptAnalysis ARGS ((void));

# endif
